/*
  Java gfx-test framework

   Copyright (C) 2010, 2011  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.testsuites;

import java.awt.Color;
import java.awt.Graphics2D;



import org.gfxtest.framework.*;
import org.gfxtest.framework.annotations.*;

/**
 * This test renders filled shapes using simple ColorPaint. Tested all following shapes:
 * Circle, Arc, Rectangle, RoundedRectangle, Polygon and Path
 *
 * @author Pavel Tisnovsky
 */
@TestType(TestTypes.RENDER_TEST)
@RenderStyle(RenderStyles.FILL)
@Transformation(Transformations.NONE)
@Zoom(1)
public class ColorPaint extends GfxTest
{
    /**
     * This method renders transparent circle using given color and transparency
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @param color
     *            circle fill color
     * @param transparency
     *            circle fill color transparency
     * @return test result status - PASSED, FAILED or ERROR
     */
    private static TestResult renderTransparentCircle(TestImage image, Graphics2D graphics, Color color, int transparency)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setTransparentFillColor(graphics, color, transparency);
        // draw the circle
        // filled by semi-transparent color
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * This method renders transparent arc using given color and transparency
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @param color
     *            circle fill color
     * @param transparency
     *            circle fill color transparency
     * @return test result status - PASSED, FAILED or ERROR
     */
    private static TestResult renderTransparentArc(TestImage image, Graphics2D graphics, Color color, int transparency)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setTransparentFillColor(graphics, color, transparency);
        // draw the arc
        // filled by semi-transparent color
        CommonShapesRenderer.drawFilledArc(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * This method renders transparent rectangle using given color and transparency
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @param color
     *            circle fill color
     * @param transparency
     *            circle fill color transparency
     * @return test result status - PASSED, FAILED or ERROR
     */
    private static TestResult renderTransparentRectangle(TestImage image, Graphics2D graphics, Color color, int transparency)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setTransparentFillColor(graphics, color, transparency);
        // draw the rectangle
        // filled by semi-transparent color
        CommonShapesRenderer.drawFilledRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * This method renders transparent rounded rectangle using given color and transparency
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @param color
     *            circle fill color
     * @param transparency
     *            circle fill color transparency
     * @return test result status - PASSED, FAILED or ERROR
     */
    private static TestResult renderTransparentRoundedRectangle(TestImage image, Graphics2D graphics, Color color, int transparency)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setTransparentFillColor(graphics, color, transparency);
        // draw the rounded rectangle
        // filled by semi-transparent color
        CommonShapesRenderer.drawFilledRoundedRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * This method renders transparent polygon using given color and transparency
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @param color
     *            circle fill color
     * @param transparency
     *            circle fill color transparency
     * @return test result status - PASSED, FAILED or ERROR
     */
    private static TestResult renderTransparentPolygon(TestImage image, Graphics2D graphics, Color color, int transparency)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setTransparentFillColor(graphics, color, transparency);
        // draw the polygon
        // filled by semi-transparent color
        CommonShapesRenderer.drawFilledPolygon(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * This method renders transparent closed path using given color and transparency
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @param color
     *            circle fill color
     * @param transparency
     *            circle fill color transparency
     * @return test result status - PASSED, FAILED or ERROR
     */
    private static TestResult renderTransparentClosedPath(TestImage image, Graphics2D graphics, Color color, int transparency)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setTransparentFillColor(graphics, color, transparency);
        // draw the closed path
        // filled by semi-transparent color
        CommonShapesRenderer.drawFilledClosedPath(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if circle drawn by graphics.drawOval() is rendered correctly.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleBasicStrokeEmptyFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // draw the circle
        CommonShapesRenderer.drawCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if circle drawn by graphics.drawOval() is rendered correctly.
     * Stroke of the circle is 10 pixels wide.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleThickStrokeEmptyFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics);
        // draw the circle
        CommonShapesRenderer.drawCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if circle drawn by graphics.drawOval() is rendered correctly.
     * Stroke of the circle is 30 pixels wide.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleExtraThickStrokeEmptyFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics);
        // draw the circle
        CommonShapesRenderer.drawCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleBasicStrokeColorFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setFillColor(graphics);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Stroke of the circle is 10 pixels wide (but it cannot affect the draw
     * process).
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleThickStrokeColorFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics);
        // set fill color
        CommonRenderingStyles.setFillColor(graphics);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Stroke of the circle is 30 pixels wide (but it cannot affect the draw
     * process).
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleExtraThickStrokeColorFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics);
        // set fill color
        CommonRenderingStyles.setFillColor(graphics);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test color paint using semi transparent color - red at 0% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleTransparentRed0FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentCircle(image, graphics, Color.red, 0);
    }

    /**
     * Test color paint using semi transparent color - red at 25% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleTransparentRed25FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentCircle(image, graphics, Color.red, 25);
    }

    /**
     * Test color paint using semi transparent color - red at 50% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleTransparentRed50FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentCircle(image, graphics, Color.red, 50);
    }

    /**
     * Test color paint using semi transparent color - red at 75% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleTransparentRed75FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentCircle(image, graphics, Color.red, 75);
    }

    /**
     * Test color paint using semi transparent color - red at 100% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleTransparentRed100FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentCircle(image, graphics, Color.red, 100);
    }

    /**
     * Test color paint using semi transparent color - green at 0% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleTransparentGreen0FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentCircle(image, graphics, Color.green, 0);
    }

    /**
     * Test color paint using semi transparent color - green at 25% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleTransparentGreen25FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentCircle(image, graphics, Color.green, 25);
    }

    /**
     * Test color paint using semi transparent color - green at 50% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleTransparentGreen50FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentCircle(image, graphics, Color.green, 50);
    }

    /**
     * Test color paint using semi transparent color - green at 75% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleTransparentGreen75FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentCircle(image, graphics, Color.green, 75);
    }

    /**
     * Test color paint using semi transparent color - green at 100% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleTransparentGreen100FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentCircle(image, graphics, Color.green, 100);
    }

    /**
     * Test color paint using semi transparent color - blue at 0% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleTransparentBlue0FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentCircle(image, graphics, Color.blue, 0);
    }

    /**
     * Test color paint using semi transparent color - blue at 25% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleTransparentBlue25FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentCircle(image, graphics, Color.blue, 25);
    }

    /**
     * Test color paint using semi transparent color - blue at 50% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleTransparentBlue50FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentCircle(image, graphics, Color.blue, 50);
    }

    /**
     * Test color paint using semi transparent color - blue at 75% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleTransparentBlue75FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentCircle(image, graphics, Color.blue, 75);
    }

    /**
     * Test color paint using semi transparent color - blue at 100% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleTransparentBlue100FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentCircle(image, graphics, Color.blue, 100);
    }

    /**
     * Test if arc drawn by graphics.drawArc() is rendered correctly.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testArcBasicStrokeEmptyFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // draw the arc
        CommonShapesRenderer.drawArc(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if arc drawn by graphics.drawArc() is rendered correctly.
     * Stroke of the arc is 10 pixels wide.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testArcThickStrokeEmptyFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics);
        // draw the arc
        CommonShapesRenderer.drawArc(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if arc drawn by graphics.drawArc() is rendered correctly.
     * Stroke of the arc is 30 pixels wide.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testArcExtraThickStrokeEmptyFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics);
        // draw the arc
        CommonShapesRenderer.drawArc(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled arc drawn by graphics.fillArc() is rendered correctly.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testArcBasicStrokeColorFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setFillColor(graphics);
        // draw the arc
        CommonShapesRenderer.drawFilledArc(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled arc drawn by graphics.fillArc() is rendered correctly.
     * Stroke of the arc is 10 pixels wide (but it cannot affect the draw
     * process).
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testArcThickStrokeColorFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics);
        // set fill color
        CommonRenderingStyles.setFillColor(graphics);
        // draw the arc
        CommonShapesRenderer.drawFilledArc(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled arc drawn by graphics.fillArc() is rendered correctly.
     * Stroke of the arc is 30 pixels wide (but it cannot affect the draw
     * process).
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testArcExtraThickStrokeColorFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics);
        // set fill color
        CommonRenderingStyles.setFillColor(graphics);
        // draw the arc
        CommonShapesRenderer.drawFilledArc(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test color paint using semi transparent color - red at 0% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testArcTransparentRed0FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentArc(image, graphics, Color.red, 0);
    }

    /**
     * Test color paint using semi transparent color - red at 25% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testArcTransparentRed25FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentArc(image, graphics, Color.red, 25);
    }

    /**
     * Test color paint using semi transparent color - red at 50% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testArcTransparentRed50FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentArc(image, graphics, Color.red, 50);
    }

    /**
     * Test color paint using semi transparent color - red at 75% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testArcTransparentRed75FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentArc(image, graphics, Color.red, 75);
    }

    /**
     * Test color paint using semi transparent color - red at 100% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testArcTransparentRed100FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentArc(image, graphics, Color.red, 100);
    }

    /**
     * Test color paint using semi transparent color - green at 0% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testArcTransparentGreen0FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentArc(image, graphics, Color.green, 0);
    }

    /**
     * Test color paint using semi transparent color - green at 25% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testArcTransparentGreen25FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentArc(image, graphics, Color.green, 25);
    }

    /**
     * Test color paint using semi transparent color - green at 50% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testArcTransparentGreen50FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentArc(image, graphics, Color.green, 50);
    }

    /**
     * Test color paint using semi transparent color - green at 75% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testArcTransparentGreen75FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentArc(image, graphics, Color.green, 75);
    }

    /**
     * Test color paint using semi transparent color - green at 100% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testArcTransparentGreen100FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentArc(image, graphics, Color.green, 100);
    }

    /**
     * Test color paint using semi transparent color - blue at 0% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testArcTransparentBlue0FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentArc(image, graphics, Color.blue, 0);
    }

    /**
     * Test color paint using semi transparent color - blue at 25% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testArcTransparentBlue25FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentArc(image, graphics, Color.blue, 25);
    }

    /**
     * Test color paint using semi transparent color - blue at 50% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testArcTransparentBlue50FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentArc(image, graphics, Color.blue, 50);
    }

    /**
     * Test color paint using semi transparent color - blue at 75% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testArcTransparentBlue75FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentArc(image, graphics, Color.blue, 75);
    }

    /**
     * Test color paint using semi transparent color - blue at 100% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testArcTransparentBlue100FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentArc(image, graphics, Color.blue, 100);
    }

    /**
     * Test if rectangle drawn by graphics.drawOval() is rendered correctly.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleBasicStrokeEmptyFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // draw the rectangle
        CommonShapesRenderer.drawRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if rectangle drawn by graphics.drawOval() is rendered correctly.
     * Stroke of the rectangle is 10 pixels wide.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleThickStrokeEmptyFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics);
        // draw the rectangle
        CommonShapesRenderer.drawRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if rectangle drawn by graphics.drawOval() is rendered correctly.
     * Stroke of the rectangle is 30 pixels wide.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleExtraThickStrokeEmptyFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics);
        // draw the rectangle
        CommonShapesRenderer.drawRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled rectangle drawn by graphics.fillOval() is rendered correctly.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleBasicStrokeColorFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setFillColor(graphics);
        // draw the rectangle
        CommonShapesRenderer.drawFilledRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled rectangle drawn by graphics.fillOval() is rendered correctly.
     * Stroke of the rectangle is 10 pixels wide (but it cannot affect the draw
     * process).
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleThickStrokeColorFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics);
        // set fill color
        CommonRenderingStyles.setFillColor(graphics);
        // draw the rectangle
        CommonShapesRenderer.drawFilledRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled rectangle drawn by graphics.fillOval() is rendered correctly.
     * Stroke of the rectangle is 30 pixels wide (but it cannot affect the draw
     * process).
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleExtraThickStrokeColorFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics);
        // set fill color
        CommonRenderingStyles.setFillColor(graphics);
        // draw the rectangle
        CommonShapesRenderer.drawFilledRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test color paint using semi transparent color - red at 0% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleTransparentRed0FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRectangle(image, graphics, Color.red, 0);
    }

    /**
     * Test color paint using semi transparent color - red at 25% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleTransparentRed25FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRectangle(image, graphics, Color.red, 25);
    }

    /**
     * Test color paint using semi transparent color - red at 50% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleTransparentRed50FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRectangle(image, graphics, Color.red, 50);
    }

    /**
     * Test color paint using semi transparent color - red at 75% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleTransparentRed75FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRectangle(image, graphics, Color.red, 75);
    }

    /**
     * Test color paint using semi transparent color - red at 100% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleTransparentRed100FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRectangle(image, graphics, Color.red, 100);
    }

    /**
     * Test color paint using semi transparent color - green at 0% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleTransparentGreen0FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRectangle(image, graphics, Color.green, 0);
    }

    /**
     * Test color paint using semi transparent color - green at 25% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleTransparentGreen25FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRectangle(image, graphics, Color.green, 25);
    }

    /**
     * Test color paint using semi transparent color - green at 50% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleTransparentGreen50FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRectangle(image, graphics, Color.green, 50);
    }

    /**
     * Test color paint using semi transparent color - green at 75% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleTransparentGreen75FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRectangle(image, graphics, Color.green, 75);
    }

    /**
     * Test color paint using semi transparent color - green at 100% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleTransparentGreen100FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRectangle(image, graphics, Color.green, 100);
    }

    /**
     * Test color paint using semi transparent color - blue at 0% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleTransparentBlue0FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRectangle(image, graphics, Color.blue, 0);
    }

    /**
     * Test color paint using semi transparent color - blue at 25% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleTransparentBlue25FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRectangle(image, graphics, Color.blue, 25);
    }

    /**
     * Test color paint using semi transparent color - blue at 50% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleTransparentBlue50FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRectangle(image, graphics, Color.blue, 50);
    }

    /**
     * Test color paint using semi transparent color - blue at 75% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleTransparentBlue75FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRectangle(image, graphics, Color.blue, 75);
    }

    /**
     * Test color paint using semi transparent color - blue at 100% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleTransparentBlue100FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRectangle(image, graphics, Color.blue, 100);
    }

    /**
     * Test if rectangle drawn by graphics.drawOval() is rendered correctly.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRoundedRectangleBasicStrokeEmptyFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // draw the rectangle
        CommonShapesRenderer.drawRoundedRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if rounded rectangle drawn by graphics.drawOval() is rendered correctly.
     * Stroke of the rounded rectangle is 10 pixels wide.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRoundedRectangleThickStrokeEmptyFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics);
        // draw the rounded rectangle
        CommonShapesRenderer.drawRoundedRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if rounded rectangle drawn by graphics.drawOval() is rendered correctly.
     * Stroke of the rounded rectangle is 30 pixels wide.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRoundedRectangleExtraThickStrokeEmptyFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics);
        // draw the rounded rectangle
        CommonShapesRenderer.drawRoundedRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled rounded rectangle drawn by graphics.fillOval() is rendered correctly.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRoundedRectangleBasicStrokeColorFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setFillColor(graphics);
        // draw the rounded rectangle
        CommonShapesRenderer.drawFilledRoundedRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled rounded rectangle drawn by graphics.fillOval() is rendered correctly.
     * Stroke of the rounded rectangle is 10 pixels wide (but it cannot affect the draw
     * process).
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRoundedRectangleThickStrokeColorFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics);
        // set fill color
        CommonRenderingStyles.setFillColor(graphics);
        // draw the rounded rectangle
        CommonShapesRenderer.drawFilledRoundedRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled rounded rectangle drawn by graphics.fillOval() is rendered correctly.
     * Stroke of the rounded rectangle is 30 pixels wide (but it cannot affect the draw
     * process).
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRoundedRectangleExtraThickStrokeColorFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics);
        // set fill color
        CommonRenderingStyles.setFillColor(graphics);
        // draw the rounded rectangle
        CommonShapesRenderer.drawFilledRoundedRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test color paint using semi transparent color - red at 0% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRoundedRectangleTransparentRed0FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRoundedRectangle(image, graphics, Color.red, 0);
    }

    /**
     * Test color paint using semi transparent color - red at 25% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRoundedRectangleTransparentRed25FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRoundedRectangle(image, graphics, Color.red, 25);
    }

    /**
     * Test color paint using semi transparent color - red at 50% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRoundedRectangleTransparentRed50FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRoundedRectangle(image, graphics, Color.red, 50);
    }

    /**
     * Test color paint using semi transparent color - red at 75% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRoundedRectangleTransparentRed75FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRoundedRectangle(image, graphics, Color.red, 75);
    }

    /**
     * Test color paint using semi transparent color - red at 100% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRoundedRectangleTransparentRed100FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRoundedRectangle(image, graphics, Color.red, 100);
    }

    /**
     * Test color paint using semi transparent color - green at 0% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRoundedRectangleTransparentGreen0FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRoundedRectangle(image, graphics, Color.green, 0);
    }

    /**
     * Test color paint using semi transparent color - green at 25% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRoundedRectangleTransparentGreen25FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRoundedRectangle(image, graphics, Color.green, 25);
    }

    /**
     * Test color paint using semi transparent color - green at 50% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRoundedRectangleTransparentGreen50FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRoundedRectangle(image, graphics, Color.green, 50);
    }

    /**
     * Test color paint using semi transparent color - green at 75% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRoundedRectangleTransparentGreen75FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRoundedRectangle(image, graphics, Color.green, 75);
    }

    /**
     * Test color paint using semi transparent color - green at 100% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRoundedRectangleTransparentGreen100FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRoundedRectangle(image, graphics, Color.green, 100);
    }

    /**
     * Test color paint using semi transparent color - blue at 0% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRoundedRectangleTransparentBlue0FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRoundedRectangle(image, graphics, Color.blue, 0);
    }

    /**
     * Test color paint using semi transparent color - blue at 25% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRoundedRectangleTransparentBlue25FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRoundedRectangle(image, graphics, Color.blue, 25);
    }

    /**
     * Test color paint using semi transparent color - blue at 50% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRoundedRectangleTransparentBlue50FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRoundedRectangle(image, graphics, Color.blue, 50);
    }

    /**
     * Test color paint using semi transparent color - blue at 75% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRoundedRectangleTransparentBlue75FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRoundedRectangle(image, graphics, Color.blue, 75);
    }

    /**
     * Test color paint using semi transparent color - blue at 100% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRoundedRectangleTransparentBlue100FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentRoundedRectangle(image, graphics, Color.blue, 100);
    }

    /**
     * Test if polygon drawn by graphics.drawOval() is rendered correctly.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testPolygonBasicStrokeEmptyFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // draw the polygon
        CommonShapesRenderer.drawPolygon(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if polygon drawn by graphics.drawOval() is rendered correctly.
     * Stroke of the polygon is 10 pixels wide.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testPolygonThickStrokeEmptyFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics);
        // draw the polygon
        CommonShapesRenderer.drawPolygon(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if polygon drawn by graphics.drawOval() is rendered correctly.
     * Stroke of the polygon is 30 pixels wide.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testPolygonExtraThickStrokeEmptyFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics);
        // draw the polygon
        CommonShapesRenderer.drawPolygon(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled polygon drawn by graphics.fillOval() is rendered correctly.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testPolygonBasicStrokeColorFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setFillColor(graphics);
        // draw the filled polygon
        CommonShapesRenderer.drawFilledPolygon(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled polygon drawn by graphics.fillOval() is rendered correctly.
     * Stroke of the polygon is 10 pixels wide (but it cannot affect the draw
     * process).
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testPolygonThickStrokeColorFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics);
        // set fill color
        CommonRenderingStyles.setFillColor(graphics);
        // draw the polygon
        CommonShapesRenderer.drawFilledPolygon(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled polygon drawn by graphics.fillOval() is rendered correctly.
     * Stroke of the polygon is 30 pixels wide (but it cannot affect the draw
     * process).
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testPolygonExtraThickStrokeColorFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics);
        // set fill color
        CommonRenderingStyles.setFillColor(graphics);
        // draw the polygon
        CommonShapesRenderer.drawFilledPolygon(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test color paint using semi transparent color - red at 0% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testPolygonTransparentRed0FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentPolygon(image, graphics, Color.red, 0);
    }

    /**
     * Test color paint using semi transparent color - red at 25% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testPolygonTransparentRed25FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentPolygon(image, graphics, Color.red, 25);
    }

    /**
     * Test color paint using semi transparent color - red at 50% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testPolygonTransparentRed50FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentPolygon(image, graphics, Color.red, 50);
    }

    /**
     * Test color paint using semi transparent color - red at 75% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testPolygonTransparentRed75FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentPolygon(image, graphics, Color.red, 75);
    }

    /**
     * Test color paint using semi transparent color - red at 100% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testPolygonTransparentRed100FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentPolygon(image, graphics, Color.red, 100);
    }

    /**
     * Test color paint using semi transparent color - green at 0% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testPolygonTransparentGreen0FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentPolygon(image, graphics, Color.green, 0);
    }

    /**
     * Test color paint using semi transparent color - green at 25% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testPolygonTransparentGreen25FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentPolygon(image, graphics, Color.green, 25);
    }

    /**
     * Test color paint using semi transparent color - green at 50% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testPolygonTransparentGreen50FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentPolygon(image, graphics, Color.green, 50);
    }

    /**
     * Test color paint using semi transparent color - green at 75% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testPolygonTransparentGreen75FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentPolygon(image, graphics, Color.green, 75);
    }

    /**
     * Test color paint using semi transparent color - green at 100% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testPolygonTransparentGreen100FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentPolygon(image, graphics, Color.green, 100);
    }

    /**
     * Test color paint using semi transparent color - blue at 0% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testPolygonTransparentBlue0FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentPolygon(image, graphics, Color.blue, 0);
    }

    /**
     * Test color paint using semi transparent color - blue at 25% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testPolygonTransparentBlue25FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentPolygon(image, graphics, Color.blue, 25);
    }

    /**
     * Test color paint using semi transparent color - blue at 50% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testPolygonTransparentBlue50FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentPolygon(image, graphics, Color.blue, 50);
    }

    /**
     * Test color paint using semi transparent color - blue at 75% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testPolygonTransparentBlue75FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentPolygon(image, graphics, Color.blue, 75);
    }

    /**
     * Test color paint using semi transparent color - blue at 100% of
     * transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testPolygonTransparentBlue100FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentPolygon(image, graphics, Color.blue, 100);
    }

    /**
     * Test if closed path drawn by graphics.fill() is
     * rendered correctly.
     *
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClosedPathBasicStrokeEmptyFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // draw the closed path
        CommonShapesRenderer.drawClosedPath(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if closed path drawn by graphics.fill() is
     * rendered correctly.
     *
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClosedPathThickStrokeEmptyFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics);
        // draw the closed path
        CommonShapesRenderer.drawClosedPath(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if closed path drawn by graphics.fill() is
     * rendered correctly.
     *
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClosedPathExtraThickStrokeEmptyFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics);
        // draw the closed path
        CommonShapesRenderer.drawClosedPath(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if closed path drawn by graphics.fill() is
     * rendered correctly.
     *
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClosedPathBasicStrokeColorFill(TestImage image, Graphics2D graphics)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics);
        // draw the filled closed path
        CommonShapesRenderer.drawFilledClosedPath(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if closed path drawn by graphics.fill() is
     * rendered correctly.
     *
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClosedPathThickStrokeColorFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics);
        // set fill color
        CommonRenderingStyles.setFillColor(graphics);
        // draw the filled closed path
        CommonShapesRenderer.drawFilledClosedPath(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if closed path drawn by graphics.fill() is
     * rendered correctly.
     *
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClosedPathExtraThickStrokeColorFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics);
        // set fill color
        CommonRenderingStyles.setFillColor(graphics);
        // draw the filled closed path
        CommonShapesRenderer.drawFilledClosedPath(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if closed path drawn by graphics.fill() is
     * rendered correctly. More preciselly - test color paint using
     * semi transparent color - red at 0% of transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClosedPathTransparentRed0FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentClosedPath(image, graphics, Color.red, 0);
    }

    /**
     * Test if closed path drawn by graphics.fill() is
     * rendered correctly. More preciselly - test color paint using
     * semi transparent color - red at 25% of transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClosedPathTransparentRed25FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentClosedPath(image, graphics, Color.red, 25);
    }

    /**
     * Test if closed path drawn by graphics.fill() is
     * rendered correctly. More preciselly - test color paint using
     * semi transparent color - red at 50% of transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClosedPathTransparentRed50FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentClosedPath(image, graphics, Color.red, 50);
    }

    /**
     * Test if closed path drawn by graphics.fill() is
     * rendered correctly. More preciselly - test color paint using
     * semi transparent color - red at 75% of transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClosedPathTransparentRed75FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentClosedPath(image, graphics, Color.red, 75);
    }

    /**
     * Test if closed path drawn by graphics.fill() is
     * rendered correctly. More preciselly - test color paint using
     * semi transparent color - red at 100% of transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClosedPathTransparentRed100FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentClosedPath(image, graphics, Color.red, 100);
    }

    /**
     * Test if closed path drawn by graphics.fill() is
     * rendered correctly. More preciselly - test color paint using
     * semi transparent color - green at 0% of transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClosedPathTransparentGreen0FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentClosedPath(image, graphics, Color.green, 0);
    }

    /**
     * Test if closed path drawn by graphics.fill() is
     * rendered correctly. More preciselly - test color paint using
     * semi transparent color - green at 25% of transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClosedPathTransparentGreen25FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentClosedPath(image, graphics, Color.green, 25);
    }

    /**
     * Test if closed path drawn by graphics.fill() is
     * rendered correctly. More preciselly - test color paint using
     * semi transparent color - green at 50% of transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClosedPathTransparentGreen50FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentClosedPath(image, graphics, Color.green, 50);
    }

    /**
     * Test if closed path drawn by graphics.fill() is
     * rendered correctly. More preciselly - test color paint using
     * semi transparent color - green at 75% of transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClosedPathTransparentGreen75FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentClosedPath(image, graphics, Color.green, 75);
    }

    /**
     * Test if closed path drawn by graphics.fill() is
     * rendered correctly. More preciselly - test color paint using
     * semi transparent color - green at 100% of transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClosedPathTransparentGreen100FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentClosedPath(image, graphics, Color.green, 100);
    }

    /**
     * Test if closed path drawn by graphics.fill() is
     * rendered correctly. More preciselly - test color paint using
     * semi transparent color - blue at 0% of transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClosedPathTransparentBlue0FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentClosedPath(image, graphics, Color.blue, 0);
    }

    /**
     * Test if closed path drawn by graphics.fill() is
     * rendered correctly. More preciselly - test color paint using
     * semi transparent color - blue at 25% of transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClosedPathTransparentBlue25FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentClosedPath(image, graphics, Color.blue, 25);
    }

    /**
     * Test if closed path drawn by graphics.fill() is
     * rendered correctly. More preciselly - test color paint using
     * semi transparent color - blue at 50% of transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClosedPathTransparentBlue50FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentClosedPath(image, graphics, Color.blue, 50);
    }

    /**
     * Test if closed path drawn by graphics.fill() is
     * rendered correctly. More preciselly - test color paint using
     * semi transparent color - blue at 75% of transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClosedPathTransparentBlue75FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentClosedPath(image, graphics, Color.blue, 75);
    }

    /**
     * Test if closed path drawn by graphics.fill() is
     * rendered correctly. More preciselly - test color paint using
     * semi transparent color - blue at 100% of transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClosedPathTransparentBlue100FillColor(TestImage image, Graphics2D graphics)
    {
        return renderTransparentClosedPath(image, graphics, Color.blue, 100);
    }

    /**
     * Entry point to the test suite.
     *
     * @param args graphics test configuration
     */
    public static void main(String[] args)
    {
        new ColorPaint().runTestSuite(args);
    }
}
