/*
  Java gfx-test framework

   Copyright (C) 2010, 2011  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.testsuites;

import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.geom.Path2D;

import org.gfxtest.framework.*;
import org.gfxtest.framework.annotations.*;



/**
 * This test renders various cubic curves using identity transformation matrix.
 * Quadratic curves are constructed using Path class.
 * 
 * @author Pavel Tisnovsky
 */
@TestType(TestTypes.RENDER_TEST)
@GraphicsPrimitive(GraphicsPrimitives.PATH)
@PathVariant(PathVariants.CUBIC_CURVE)
@RenderStyle(RenderStyles.NORMAL)
@Transformation(Transformations.NONE)
@Zoom(1)
public class NormalCubicCurvesAsPaths extends GfxTest
{

    /**
     * Default Y offset of cubic curve end points.
     */
    private static final int DEFAULT_Y_OFFSET_FOR_CUBIC_CURVES = -20;

    /**
     * Step between curves drawn by different colors onto the same image.
     */
    private static final int OFFSET_STEP = 20;

    /**
     * Draw crosses at the both end points and both control points of cubic
     * curve.
     * 
     * @param graphics
     *            graphics canvas
     * @param xarray
     *            array containing x coordinates of all four control points of
     *            cubic curve
     * @param yarray
     *            array containing y coordinates of all four control points of
     *            cubic curve
     * @param pointIndexes
     *            indexes of control point to use to draw the curve (default
     *            value should be {1,2,3,4})
     */
    private void drawCrossesAtControlPoints(Graphics2D graphics, int[] xarray, int[] yarray, int[] pointIndexes)
    {
        for (int i = 0; i < 4; i++)
        {
            drawCross(graphics, xarray[pointIndexes[i]-1], yarray[pointIndexes[i]-1]);
        }
    }

    /**
     * Draw cubic curve onto canvas specified by Graphics2D class.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics canvas
     * @param path
     *            curve contained in the path to be drawn
     * @param color
     *            curve color or null when Color.BLACK can be used.
     * @param pointIndexes
     *            indexes of control point to use to draw the curve (default
     *            value should be {1,2,3,4})
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult drawPath(TestImage image, Graphics2D graphics, Path2D path, Color color, int[] pointIndexes)
    {
        // construct point set which consists of all four curve control points
        CubicCurvePointSet pointSet = new CubicCurvePointSet(image);

        // fill in arrays containing coordinates for all cubic curve control points
        int[] x = pointSet.getXPointArray();
        int[] y = pointSet.getYPointArray();

        // set curve color
        graphics.setColor(color);

        // draw the cubic curve
        graphics.draw(path);

        // Draw crosses at the both end points and both control points of cubic
        // curve.
        drawCrossesAtControlPoints(graphics, x, y, pointIndexes);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Draw cubic curve onto canvas specified by Graphics2D class.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics canvas
     * @param path
     *            curve contained in the path to be drawn
     * @param color
     *            curve color or null when Color.BLACK can be used.
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult drawPath(TestImage image, Graphics2D graphics, Path2D path, Color color)
    {
        return drawPath(image, graphics, path, color, new int[] { 1, 2, 3, 4 });
    }

    /**
     * Draw cubic curve onto canvas specified by Graphics2D class.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics canvas
     * @param path
     *            curve contained in the path to be drawn
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult drawPath(TestImage image, Graphics2D graphics, Path2D path)
    {
        return drawPath(image, graphics, path, Color.BLACK);
    }

    /**
     * Draw set of cubic curves onto canvas specified by Graphics2D class.
     * Curves are drawn using various colors.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics canvas
     */
    private void drawCurveWithVariousColorsFloat(TestImage image, Graphics2D graphics)
    {
        // construct point set which consists of all four curve control points
        CubicCurvePointSet pointSet = new CubicCurvePointSet(image);

        // fill in arrays containing coordinates for all cubic curve control points
        int[] xarray = pointSet.getXPointArray();
        int[] yarray = pointSet.getYPointArray();

        // curve colors
        Color[] colors = ColorPalette.getColors();

        // offset counter
        int offset = DEFAULT_Y_OFFSET_FOR_CUBIC_CURVES;

        // Draw each curve with different color.
        for (Color color : colors)
        {
            // create new path
            Path2D path = CommonPathsGenerator.createCubicPathFloat(image, xarray, yarray, new int[] {1,2,3,4}, offset);

            // set the specified color
            graphics.setColor(color);

            // draw QuadCurve2D
            graphics.draw(path);

            // move next curve down
            offset += OFFSET_STEP;
        }
    }

    /**
     * Draw set of cubic curves onto canvas specified by Graphics2D class.
     * Curves are drawn using various colors.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics canvas
     */
    private void drawCurveWithVariousColorsDouble(TestImage image, Graphics2D graphics)
    {
        // construct point set which consists of all four curve control points
        CubicCurvePointSet pointSet = new CubicCurvePointSet(image);

        // fill in arrays containing coordinates for all cubic curve control points
        int[] xarray = pointSet.getXPointArray();
        int[] yarray = pointSet.getYPointArray();

        // curve colors
        Color[] colors = ColorPalette.getColors();

        // offset counter
        int offset = DEFAULT_Y_OFFSET_FOR_CUBIC_CURVES;

        // Draw each curve with different color.
        for (Color color : colors)
        {
            // create new path
            Path2D path = CommonPathsGenerator.createCubicPathDouble(image, xarray, yarray, new int[] {1,2,3,4}, offset);

            // set the specified color
            graphics.setColor(color);

            // draw QuadCurve2D
            graphics.draw(path);

            // move next curve down
            offset += OFFSET_STEP;
        }
    }

    /**
     * Draw set of cubic curves onto canvas specified by Graphics2D class.
     * Curves are drawn using various transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics canvas
     */
    private void drawCurveWithVariousTransparencyFloat(TestImage image, Graphics2D graphics)
    {
        // construct point set which consists of all four curve control points
        CubicCurvePointSet pointSet = new CubicCurvePointSet(image);

        // fill in arrays containing coordinates for all cubic curve control points
        int[] xarray = pointSet.getXPointArray();
        int[] yarray = pointSet.getYPointArray();

        // offset counter
        int offset = DEFAULT_Y_OFFSET_FOR_CUBIC_CURVES;

        // Draw each curve with transparency
        for (int transparency = 0; transparency < 16; transparency++)
        {
            // create new path
            Path2D path = CommonPathsGenerator.createCubicPathFloat(image, xarray, yarray, new int[] {1,2,3,4}, offset);

            // set the specified color
            graphics.setColor(new Color(0f, 0f, 0f, transparency / 16f));

            // draw QuadCurve2D
            graphics.draw(path);

            // move next curve down
            offset += OFFSET_STEP;
        }
    }

    /**
     * Draw set of cubic curves onto canvas specified by Graphics2D class.
     * Curves are drawn using various transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics canvas
     */
    private void drawCurveWithVariousTransparencyDouble(TestImage image, Graphics2D graphics)
    {
        // construct point set which consists of all four curve control points
        CubicCurvePointSet pointSet = new CubicCurvePointSet(image);

        // fill in arrays containing coordinates for all cubic curve control points
        int[] xarray = pointSet.getXPointArray();
        int[] yarray = pointSet.getYPointArray();

        // offset counter
        int offset = DEFAULT_Y_OFFSET_FOR_CUBIC_CURVES;

        // Draw each curve with transparency
        for (int transparency = 0; transparency < 16; transparency++)
        {
            // create new path
            Path2D path = CommonPathsGenerator.createCubicPathDouble(image, xarray, yarray, new int[] {1,2,3,4}, offset);

            // set the specified color
            graphics.setColor(new Color(0f, 0f, 0f, transparency / 16f));

            // draw QuadCurve2D
            graphics.draw(path);

            // move next curve down
            offset += OFFSET_STEP;
        }
    }

    /**
     * Create cubic cube and draw it.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult createAndDrawPathFloat(TestImage image, Graphics2D graphics)
    {
        // create new path
        Path2D path = CommonPathsGenerator.createCubicPathFloat(image);

        // draw path
        return drawPath(image, graphics, path);
    }

    /**
     * Create cubic cube and draw it.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult createAndDrawPathDouble(TestImage image, Graphics2D graphics)
    {
        // create new path
        Path2D path = CommonPathsGenerator.createCubicPathDouble(image);

        // draw path
        return drawPath(image, graphics, path);
    }

    /**
     * Test if cubic curve created by Path2D.Float() is rendered correctly.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBasicCubicCurveFloat(TestImage image, Graphics2D graphics)
    {
        // create cubic curve and draw it
        Path2D path = CommonPathsGenerator.createCubicPathFloat(image);
        return drawPath(image, graphics, path);
    }

    /**
     * Test if cubic curve created by Path2D.Double() is rendered correctly.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBasicCubicCurveDouble(TestImage image, Graphics2D graphics)
    {
        // create cubic curve and draw it
        Path2D path = CommonPathsGenerator.createCubicPathDouble(image);
        return drawPath(image, graphics, path);
    }

    /**
     * Test if cubic curve created by Path2D.Float() is rendered
     * correctly. Curve is to be drawn with zero pixels wide stroke and default
     * caps.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testZeroStrokeFloat(TestImage image, Graphics2D graphics)
    {
        // set zero pixels wide stroke
        CommonRenderingStyles.setStrokeZeroThick(graphics);

        // create cubic curve and draw it
        return createAndDrawPathFloat(image, graphics);
    }

    /**
     * Test if cubic curve created by Path2D.Float() is rendered
     * correctly. Curve is to be drawn with zero pixels wide stroke and default
     * caps.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testZeroStrokeDouble(TestImage image, Graphics2D graphics)
    {
        // set zero pixels wide stroke
        CommonRenderingStyles.setStrokeZeroThick(graphics);

        // create cubic curve and draw it
        return createAndDrawPathDouble(image, graphics);
    }

    /**
     * Test if cubic curve created by Path2D.Float() is rendered
     * correctly. Curve is to be drawn with zero pixels wide stroke and butt
     * caps.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testZeroStrokeCapsButtFloat(TestImage image, Graphics2D graphics)
    {
        // set zero pixels wide stroke
        CommonRenderingStyles.setStrokeZeroThick(graphics, BasicStroke.CAP_BUTT);

        // create cubic path and draw it
        return createAndDrawPathFloat(image, graphics);
    }

    /**
     * Test if cubic curve created by Path2D.Double() is rendered
     * correctly. Curve is to be drawn with zero pixels wide stroke and butt
     * caps.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testZeroStrokeCapsButtDouble(TestImage image, Graphics2D graphics)
    {
        // set zero pixels wide stroke
        CommonRenderingStyles.setStrokeZeroThick(graphics, BasicStroke.CAP_BUTT);

        // create cubic path and draw it
        return createAndDrawPathDouble(image, graphics);
    }

    /**
     * Test if cubic curve created by Path2D.Float() is rendered
     * correctly. Curve is to be drawn with zero pixels wide stroke and round
     * caps.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testZeroStrokeCapsRoundFloat(TestImage image, Graphics2D graphics)
    {
        // set zero pixels wide stroke
        CommonRenderingStyles.setStrokeZeroThick(graphics, BasicStroke.CAP_ROUND);

        // create cubic path and draw it
        return createAndDrawPathFloat(image, graphics);
    }

    /**
     * Test if cubic curve created by Path2D.Double() is rendered
     * correctly. Curve is to be drawn with zero pixels wide stroke and default
     * caps.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testZeroStrokeCapsRoundDouble(TestImage image, Graphics2D graphics)
    {
        // set zero pixels wide stroke
        CommonRenderingStyles.setStrokeZeroThick(graphics, BasicStroke.CAP_ROUND);

        // create cubic path and draw it
        return createAndDrawPathDouble(image, graphics);
    }

    /**
     * Test if cubic curve created by Path2D.Float() is rendered
     * correctly. Curve is to be drawn with zero pixels wide stroke and square
     * caps.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testZeroStrokeCapsSquareFloat(TestImage image, Graphics2D graphics)
    {
        // set zero pixels wide stroke
        CommonRenderingStyles.setStrokeZeroThick(graphics, BasicStroke.CAP_SQUARE);

        // create cubic path and draw it
        return createAndDrawPathFloat(image, graphics);
    }

    /**
     * Test if cubic curve created by Path2D.Double() is rendered
     * correctly. Curve is to be drawn with zero pixels wide stroke and square
     * caps.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testZeroStrokeCapsSquareDouble(TestImage image, Graphics2D graphics)
    {
        // set zero pixels wide stroke
        CommonRenderingStyles.setStrokeZeroThick(graphics, BasicStroke.CAP_SQUARE);

        // create cubic path and draw it
        return createAndDrawPathDouble(image, graphics);
    }

    /**
     * Test if cubic curve created by Path2D.Float() is rendered
     * correctly. Curve is to be drawn with 10 pixels wide stroke and default
     * caps.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testThickStrokeFloat(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics);

        // create cubic curve and draw it
        return createAndDrawPathFloat(image, graphics);
    }

    /**
     * Test if cubic curve created by Path2D.Double() is rendered
     * correctly. Curve is to be drawn with 10 pixels wide stroke and default
     * caps.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testThickStrokeDouble(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics);

        // create cubic curve and draw it
        return createAndDrawPathDouble(image, graphics);
    }

    /**
     * Test if cubic curve created by Path2D.Float() is rendered correctly.
     * Curve is to be drawn with 10 pixels wide stroke and the curve caps is set
     * to CAP_BUTT.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testThickStrokeCapsButtFloat(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics, BasicStroke.CAP_BUTT, BasicStroke.JOIN_BEVEL);

        // create cubic curve and draw it
        return createAndDrawPathFloat(image, graphics);
    }

    /**
     * Test if cubic curve created by Path2D.Double() is rendered correctly.
     * Curve is to be drawn with 10 pixels wide stroke and the curve caps is set
     * to CAP_BUTT.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testThickStrokeCapsButtDouble(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics, BasicStroke.CAP_BUTT, BasicStroke.JOIN_BEVEL);

        // create cubic curve and draw it
        return createAndDrawPathDouble(image, graphics);
    }

    /**
     * Test if cubic curve created by Path2D.Float() is rendered correctly.
     * Curve is to be drawn with 10 pixels wide stroke and the curve caps is set
     * to CAP_ROUND.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testThickStrokeCapsRoundFloat(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL);

        // create cubic curve and draw it
        return createAndDrawPathFloat(image, graphics);
    }

    /**
     * Test if cubic curve created by Path2D.Double() is rendered correctly.
     * Curve is to be drawn with 10 pixels wide stroke and the curve caps is set
     * to CAP_ROUND.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testThickStrokeCapsRoundDouble(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL);

        // create cubic curve and draw it
        return createAndDrawPathDouble(image, graphics);
    }

    /**
     * Test if cubic curve created by Path2D.Float() is rendered correctly.
     * Curve is to be drawn with 10 pixels wide stroke and the curve caps is set
     * to CAP_SQUARE.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testThickStrokeCapsSquareFloat(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_BEVEL);

        // create cubic curve and draw it
        return createAndDrawPathFloat(image, graphics);
    }

    /**
     * Test if cubic curve created by Path2D.Double() is rendered correctly.
     * Curve is to be drawn with 10 pixels wide stroke and the curve caps is set
     * to CAP_SQUARE.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testThickStrokeCapsSquareDouble(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_BEVEL);

        // create cubic curve and draw it
        return createAndDrawPathDouble(image, graphics);
    }

    /**
     * Test if cubic curve created by Path2D.Float() is rendered
     * correctly. Curve is to be drawn with 30 pixels wide stroke and default
     * caps.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testExtraThickStrokeFloat(TestImage image, Graphics2D graphics)
    {
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics);

        // create cubic curve and draw it
        return createAndDrawPathFloat(image, graphics);
    }

    /**
     * Test if cubic curve created by Path2D.Double() is rendered
     * correctly. Curve is to be drawn with 30 pixels wide stroke and default
     * caps.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testExtraThickStrokeDouble(TestImage image, Graphics2D graphics)
    {
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics);

        // create cubic curve and draw it
        return createAndDrawPathDouble(image, graphics);
    }

    /**
     * Test if cubic curve created by Path2D.Float() is rendered correctly.
     * Curve is to be drawn with 30 pixels wide stroke and the curve caps is set
     * to CAP_BUTT.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testExtraThickStrokeCapsButtFloat(TestImage image, Graphics2D graphics)
    {
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics, BasicStroke.CAP_BUTT, BasicStroke.JOIN_BEVEL);

        // create cubic curve and draw it
        return createAndDrawPathFloat(image, graphics);
    }

    /**
     * Test if cubic curve created by Path2D.Double() is rendered correctly.
     * Curve is to be drawn with 30 pixels wide stroke and the curve caps is set
     * to CAP_BUTT.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testExtraThickStrokeCapsButtDouble(TestImage image, Graphics2D graphics)
    {
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics, BasicStroke.CAP_BUTT, BasicStroke.JOIN_BEVEL);

        // create cubic curve and draw it
        return createAndDrawPathDouble(image, graphics);
    }

    /**
     * Test if cubic curve created by Path2D.Float() is rendered correctly.
     * Curve is to be drawn with 30 pixels wide stroke and the curve caps is set
     * to CAP_ROUND.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testExtraThickStrokeCapsRoundFloat(TestImage image, Graphics2D graphics)
    {
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL);

        // create cubic curve and draw it
        return createAndDrawPathFloat(image, graphics);
    }

    /**
     * Test if cubic curve created by Path2D.Double() is rendered correctly.
     * Curve is to be drawn with 30 pixels wide stroke and the curve caps is set
     * to CAP_ROUND.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testExtraThickStrokeCapsRoundDouble(TestImage image, Graphics2D graphics)
    {
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL);

        // create cubic curve and draw it
        return createAndDrawPathDouble(image, graphics);
    }

    /**
     * Test if cubic curve created by Path2D.Float() is rendered correctly.
     * Curve is to be drawn with 30 pixels wide stroke and the curve caps is set
     * to CAP_SQUARE.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testExtraThickStrokeCapsSquareFloat(TestImage image, Graphics2D graphics)
    {
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_BEVEL);

        // create cubic curve and draw it
        return createAndDrawPathFloat(image, graphics);
    }

    /**
     * Test if cubic curve created by Path2D.Double() is rendered correctly.
     * Curve is to be drawn with 30 pixels wide stroke and the curve caps is set
     * to CAP_SQUARE.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testExtraThickStrokeCapsSquareDouble(TestImage image, Graphics2D graphics)
    {
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_BEVEL);

        // create cubic curve and draw it
        return createAndDrawPathDouble(image, graphics);
    }

    /**
     * Test if cubic curve created by Path2D.Float() is rendered
     * correctly. Curve is drawn using different colors.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testColorsBasicStrokeFloat(TestImage image, Graphics2D graphics)
    {
        // draw set of curves using test color palette
        drawCurveWithVariousColorsFloat(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if cubic curve created by Path2D.Double() is rendered
     * correctly. Curve is drawn using different colors.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testColorsBasicStrokeDouble(TestImage image, Graphics2D graphics)
    {
        // draw set of curves using test color palette
        drawCurveWithVariousColorsDouble(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if cubic curve created by Path2D.Float() is rendered correctly.
     * Curve is drawn using different colors and using 10 pixel wide stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testColorsThickStrokeFloat(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics); 

        // draw set of curves using test color palette
        drawCurveWithVariousColorsFloat(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if cubic curve created by Path2D.Double() is rendered correctly.
     * Curve is drawn using different colors and using 10 pixel wide stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testColorsThickStrokeDouble(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics); 

        // draw set of curves using test color palette
        drawCurveWithVariousColorsDouble(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if cubic curve created by Path2D.Float() is rendered correctly.
     * Curve is drawn using different colors and using 30 pixel wide stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testColorsExtraThickStrokeFloat(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics); 

        // draw set of curves using test color palette
        drawCurveWithVariousColorsFloat(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if cubic curve created by Path2D.Double() is rendered correctly.
     * Curve is drawn using different colors and using 30 pixel wide stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testColorsExtraThickStrokeDouble(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics); 

        // draw set of curves using test color palette
        drawCurveWithVariousColorsDouble(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if cubic curve created by Path2D.Float() is rendered correctly.
     * Curve is drawn using different colors and using zero pixel wide stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testColorsZeroThickStrokeFloat(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeZeroThick(graphics); 

        // draw set of curves using test color palette
        drawCurveWithVariousColorsFloat(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if cubic curve created by Path2D.Double() is rendered correctly.
     * Curve is drawn using different colors and using zero pixel wide stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testColorsZeroThickStrokeDouble(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeZeroThick(graphics); 

        // draw set of curves using test color palette
        drawCurveWithVariousColorsDouble(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if cubic curve created by Path2D.Float() is rendered correctly.
     * Curve is drawn using different colors and using 10 pixel wide stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testColorsCapsButtFloat(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics, BasicStroke.CAP_BUTT, BasicStroke.JOIN_BEVEL); 

        // draw set of curves using test color palette
        drawCurveWithVariousColorsFloat(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if cubic curve created by Path2D.Double() is rendered correctly.
     * Curve is drawn using different colors and using 10 pixel wide stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testColorsCapsButtDouble(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics, BasicStroke.CAP_BUTT, BasicStroke.JOIN_BEVEL); 

        // draw set of curves using test color palette
        drawCurveWithVariousColorsDouble(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if cubic curve created by Path2D.Float() is rendered correctly.
     * Curve is drawn using different colors and using 10 pixel wide stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testColorsCapsRoundFloat(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL); 

        // draw set of curves using test color palette
        drawCurveWithVariousColorsFloat(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if cubic curve created by Path2D.Double() is rendered correctly.
     * Curve is drawn using different colors and using 10 pixel wide stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testColorsCapsRoundDouble(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL); 

        // draw set of curves using test color palette
        drawCurveWithVariousColorsDouble(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if cubic curve created by Path2D.Float() is rendered correctly.
     * Curve is drawn using different colors and using 10 pixel wide stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testColorsCapsSquareFloat(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_BEVEL);

        // draw set of curves using test color palette
        drawCurveWithVariousColorsFloat(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if cubic curve created by Path2D.Double() is rendered correctly.
     * Curve is drawn using different colors and using 10 pixel wide stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testColorsCapsSquareDouble(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_BEVEL);

        // draw set of curves using test color palette
        drawCurveWithVariousColorsDouble(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if cubic curve created by CubicCurve2D.Float() is rendered correctly.
     * Curve is drawn using different transparency and using 1 pixel wide
     * stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testTransparencyBasicStrokeFloat(TestImage image, Graphics2D graphics)
    {
        // draw set of curves using different transparency
        drawCurveWithVariousTransparencyFloat(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if cubic curve created by CubicCurve2D.Double() is rendered correctly.
     * Curve is drawn using different transparency and using 1 pixel wide
     * stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testTransparencyBasicStrokeDouble(TestImage image, Graphics2D graphics)
    {
        // draw set of curves using different transparency
        drawCurveWithVariousTransparencyDouble(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if cubic curve created by CubicCurve2D.Float() is rendered correctly.
     * Curve is drawn using different transparency and using 10 pixel wide
     * stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testTransparencyThickStrokeFloat(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics);

        // draw set of curves using different transparency
        drawCurveWithVariousTransparencyFloat(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if cubic curve created by CubicCurve2D.Double() is rendered correctly.
     * Curve is drawn using different transparency and using 10 pixel wide
     * stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testTransparencyThickStrokeDouble(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics);

        // draw set of curves using different transparency
        drawCurveWithVariousTransparencyDouble(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if cubic curve created by CubicCurve2D.Float() is rendered correctly.
     * Curve is drawn using different transparency and using 30 pixel wide
     * stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testTransparencyExtraThickStrokeFloat(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics);

        // draw set of curves using different transparency
        drawCurveWithVariousTransparencyFloat(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if cubic curve created by CubicCurve2D.Double() is rendered correctly.
     * Curve is drawn using different transparency and using 30 pixel wide
     * stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testTransparencyExtraThickStrokeDouble(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics);

        // draw set of curves using different transparency
        drawCurveWithVariousTransparencyDouble(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if cubic curve created by CubicCurve2D.Float() is rendered correctly.
     * Curve is drawn using different transparency and using 30 pixel wide
     * stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testTransparencyZeroThickStrokeFloat(TestImage image, Graphics2D graphics)
    {
        // set zero pixels wide stroke
        CommonRenderingStyles.setStrokeZeroThick(graphics);

        // draw set of curves using different transparency
        drawCurveWithVariousTransparencyFloat(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if cubic curve created by CubicCurve2D.Double() is rendered correctly.
     * Curve is drawn using different transparency and using 30 pixel wide
     * stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testTransparencyZeroThickStrokeDouble(TestImage image, Graphics2D graphics)
    {
        // set zero pixels wide stroke
        CommonRenderingStyles.setStrokeZeroThick(graphics);

        // draw set of curves using different transparency
        drawCurveWithVariousTransparencyDouble(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Entry point to the test suite.
     * 
     * @param args
     *            not used in this case
     */
    public static void main(String[] args)
    {
        new NormalCubicCurvesAsPaths().runTestSuite(args);
    }
}
